@@ -13,7 +13,7 @@
  * documentation.  This software is provided "as is" without expressed or
  * implied warranty.
 
- * Creation: Thu Apr 23 18:24:59 MET DST 1992 on dec1.wu-wien.ac.at
+ * Creation: Sat Aug  1 23:38:31 MET DST 1992 on dec4.wu-wien.ac.at
  * Author: genc
  * Version: 0.9
  */
@@ -54,7 +54,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Source(argv[1])))
+     if (!(localVar1 = (Widget) name2Source(argv[1])))
           {
           convError("textSourceRead","1",argv[1],"TextSource");
           DBUG_RETURN (TCL_ERROR);
@@ -124,7 +124,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Source(argv[1])))
+     if (!(localVar1 = (Widget) name2Source(argv[1])))
           {
           convError("textSourceScan","1",argv[1],"TextSource");
           DBUG_RETURN (TCL_ERROR);
@@ -229,13 +229,13 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Sink(argv[1])))
+     if (!(localVar1 = (Widget) name2Sink(argv[1])))
           {
           convError("textSinkMaxLines","1",argv[1],"TextSink");
           DBUG_RETURN (TCL_ERROR);
           }
 
-     if (!(sscanf(argv[2], "%ld", &localVar2)))
+     if (!(sscanf(argv[2], "%hu", &localVar2)))
           {
           convError("textSinkMaxLines","2",argv[2],"Dimension");
           DBUG_RETURN (TCL_ERROR);
@@ -254,7 +254,7 @@ sprintf(conversionBuffer, "%d", returnVar);
  * int
  * XawTextSinkMaxHeight
  * 	in: (Widget)TextSink
- * 	in: Dimension
+ * 	in: int
  */
 
 int 
@@ -265,7 +265,7 @@ int           argc;
 char        **argv;
      {
      Widget localVar1;
-     Dimension localVar2;
+     int localVar2;
      int returnVar;
      char conversionBuffer[100];
 
@@ -277,15 +277,15 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Sink(argv[1])))
+     if (!(localVar1 = (Widget) name2Sink(argv[1])))
           {
           convError("textSinkMaxHeight","1",argv[1],"TextSink");
           DBUG_RETURN (TCL_ERROR);
           }
 
-     if (!(sscanf(argv[2], "%ld", &localVar2)))
+     if (!(sscanf(argv[2], "%d", &localVar2)))
           {
-          convError("textSinkMaxHeight","2",argv[2],"Dimension");
+          convError("textSinkMaxHeight","2",argv[2],"int");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -323,7 +323,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("textSetSelectionArray","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -367,6 +367,7 @@ char        **argv;
           }
      }
      XawTextSetSelectionArray(localVar1,localVar2);
+     MMreplace(MMgetAttribList(localVar1),XrmStringToQuark("textSetSelectionArray"),(char*)localVar2);
 
      DBUG_RETURN (TCL_OK);
      }     
@@ -398,7 +399,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Sink(argv[1])))
+     if (!(localVar1 = (Widget) name2Sink(argv[1])))
           {
           convError("textSinkSetTabs","1",argv[1],"TextSink");
           DBUG_RETURN (TCL_ERROR);
@@ -421,6 +422,7 @@ char        **argv;
           }
      }
      XawTextSinkSetTabs(localVar1,argc-2,localVar2);
+     MMreplace(MMgetAttribList(localVar1),XrmStringToQuark("textSinkSetTabs"),(char*)localVar2);
 
      DBUG_RETURN (TCL_OK);
      }     
@@ -455,7 +457,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("textSearch","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -546,7 +548,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("textInvalidate","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -593,7 +595,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("textEnableRedisplay","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -628,7 +630,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("textDisableRedisplay","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -663,7 +665,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("textDisplay","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -700,7 +702,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("textTopPosition","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -740,7 +742,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("textSetInsertionPoint","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -783,7 +785,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("textGetInsertionPoint","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -823,7 +825,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("textDisplayCaret","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -875,7 +877,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("textGetSelectionPos","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -920,7 +922,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("textSetSelection","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -967,7 +969,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("textUnsetSelection","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1010,7 +1012,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("textReplace","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1104,7 +1106,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("asciiSaveAsFile","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1143,7 +1145,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("asciiSourceFreeString","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1180,7 +1182,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("asciiSave","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1226,7 +1228,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("asciiSourceChanged","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1274,7 +1276,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("formDoLayout","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1327,7 +1329,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("toggleSetRadioData","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1365,7 +1367,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("toggleChangeRadioGroup","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1374,7 +1376,7 @@ char        **argv;
      if (!strcmp(argv[2], "NULL")) 
          localVar2 = NULL;
      else
-     if (!(localVar2 = name2Widget(argv[2])))
+     if (!(localVar2 = (Widget) name2Widget(argv[2])))
           {
           convError("toggleChangeRadioGroup","2",argv[2],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1411,7 +1413,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("toggleSetCurrent","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1448,7 +1450,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("toggleGetCurrent","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1486,7 +1488,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("toggleUnsetCurrent","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1539,19 +1541,19 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("talk","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
           }
 
-     if (!(localVar2 = name2Widget(argv[2])))
+     if (!(localVar2 = (Widget) name2Widget(argv[2])))
           {
           convError("talk","2",argv[2],"Widget");
           DBUG_RETURN (TCL_ERROR);
           }
 
-     if (!(localVar3 = name2Widget(argv[3])))
+     if (!(localVar3 = (Widget) name2Widget(argv[3])))
           {
           convError("talk","3",argv[3],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1588,7 +1590,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("listUnhighlight","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1625,7 +1627,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("listHighlight","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1668,7 +1670,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("listShowCurrent","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1687,6 +1689,57 @@ char        **argv;
      }     
 
 
+#ifdef XEDW
+#include "Xedw/XedwList.h"
+
+/* 
+ * hint: XEDW
+ * XedwListReturnStruct *
+ * XedwListShowCurrent
+ * 	in: Widget
+ */
+#ifdef XEDW
+
+int 
+com_edwListShowCurrent(clientData, comInterpreter, argc, argv)
+ClientData    clientData;
+Tcl_Interp   *comInterpreter;
+int           argc;
+char        **argv;
+     {
+     Widget localVar1;
+     XedwListReturnStruct * returnVar;
+     char conversionBuffer[100];
+
+     DBUG_ENTER("edwListShowCurrent");  
+
+     if (argc != 2) 
+	 {
+	 argcError("edwListShowCurrent","",1,argc);
+	 DBUG_RETURN (TCL_ERROR);
+         }
+
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
+          {
+          convError("edwListShowCurrent","1",argv[1],"Widget");
+          DBUG_RETURN (TCL_ERROR);
+          }
+
+     returnVar = XedwListShowCurrent(localVar1);
+
+     
+     Tcl_SetVar2(interpreter,"returnVar","string", returnVar->string,0);
+     sprintf(conversionBuffer, "%d", returnVar->xedwList_index);
+     Tcl_SetVar2(interpreter,"returnVar","xedwList_index", conversionBuffer,0);
+
+     Tcl_SetResult(comInterpreter, "returnVar", TCL_VOLATILE);
+
+     DBUG_RETURN (TCL_OK);
+     }     
+#endif
+
+#endif
+
 #ifndef PRER5
 #include <X11/Xaw/Tree.h>
 #endif
@@ -1716,7 +1769,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("treeForceLayout","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1757,7 +1810,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("scrollbarSetThumb","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1808,7 +1861,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("scSet","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1852,7 +1905,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("dialogGetValueString","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1894,7 +1947,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("panedAllowResize","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1945,7 +1998,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("panedSetMinMax","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1997,7 +2050,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("panedGetMinMax","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -2040,7 +2093,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("panedSetRefigureMode","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -2089,7 +2142,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("panedGetNumSub","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -2131,7 +2184,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("simpleMenuGetActiveEntry","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -2169,7 +2222,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("simpleMenuClearActiveEntry","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
