@@ -13,7 +13,7 @@
  * documentation.  This software is provided "as is" without expressed or
  * implied warranty.
 
- * Creation: Tue Apr 21 15:05:25 MET DST 1992 on dec1.wu-wien.ac.at
+ * Creation: Sat Aug  1 15:24:00 MET DST 1992 on dec4.wu-wien.ac.at
  * Author: genc
  * Version: 0.9
  */
@@ -45,7 +45,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("popdown","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -80,7 +80,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("popupSpringLoaded","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -117,7 +117,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("popup","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -148,7 +148,7 @@ char        **argv;
  * void
  * XtDestroyWidget
  * 	callmultiple
- * 		in: Widget
+ * 		in: freeGarbageMM(Widget)
  */
 
 int 
@@ -171,13 +171,13 @@ char        **argv;
 
      for (count = 1; count < argc; count++)
          {
-         if (!(localVar1 = name2Widget(argv[count])))
+         if (!(localVar1 = (Widget) name2Widget(argv[count])))
               {
               convError("destroyWidget","count",argv[count],"Widget");
               DBUG_RETURN (TCL_ERROR);
               }
 
-         XtDestroyWidget(localVar1);
+         XtDestroyWidget(freeGarbageMM(localVar1));
           }
 
      DBUG_RETURN (TCL_OK);
@@ -211,7 +211,7 @@ char        **argv;
 
      for (count = 1; count < argc; count++)
          {
-         if (!(localVar1 = name2Widget(argv[count])))
+         if (!(localVar1 = (Widget) name2Widget(argv[count])))
               {
               convError("unrealizeWidget","count",argv[count],"Widget");
               DBUG_RETURN (TCL_ERROR);
@@ -251,7 +251,7 @@ char        **argv;
 
      for (count = 1; count < argc; count++)
          {
-         if (!(localVar1 = name2Widget(argv[count])))
+         if (!(localVar1 = (Widget) name2Widget(argv[count])))
               {
               convError("manageChild","count",argv[count],"Widget");
               DBUG_RETURN (TCL_ERROR);
@@ -289,13 +289,13 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("setKeyboardFocus","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
           }
 
-     if (!(localVar2 = name2Widget(argv[2])))
+     if (!(localVar2 = (Widget) name2Widget(argv[2])))
           {
           convError("setKeyboardFocus","2",argv[2],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -343,7 +343,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("grabPointer","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -385,7 +385,7 @@ char        **argv;
         }
 
 
-     if (!(localVar5 = name2Widget(argv[5])))
+     if (!(localVar5 = (Widget) name2Widget(argv[5])))
           {
           convError("grabPointer","6",argv[5],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -436,7 +436,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("ungrabPointer","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -480,7 +480,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("grabKeyboard","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -567,7 +567,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("ungrabKeyboard","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -634,7 +634,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("getTypeOfAttribute","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -650,6 +650,48 @@ char        **argv;
      }     
 
 
+#include <X11/IntrinsicP.h>
+#define getClass(widget) (XtClass(widget)->core_class.class_name)
+
+/* 
+ * char *
+ * getClass
+ * 	in: Widget
+ */
+
+int 
+com_getClass(clientData, comInterpreter, argc, argv)
+ClientData    clientData;
+Tcl_Interp   *comInterpreter;
+int           argc;
+char        **argv;
+     {
+     Widget localVar1;
+     char * returnVar;
+
+     DBUG_ENTER("getClass");  
+
+     if (argc != 2) 
+	 {
+	 argcError("getClass","",1,argc);
+	 DBUG_RETURN (TCL_ERROR);
+         }
+
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
+          {
+          convError("getClass","1",argv[1],"Widget");
+          DBUG_RETURN (TCL_ERROR);
+          }
+
+     returnVar = getClass(localVar1);
+
+
+     Tcl_SetResult(comInterpreter, returnVar, TCL_VOLATILE);
+
+     DBUG_RETURN (TCL_OK);
+     }     
+
+
 #include <signal.h>
 
 /* 
@@ -784,19 +826,19 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("installAccelerators","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
           }
 
-     if (!(localVar2 = name2Widget(argv[2])))
+     if (!(localVar2 = (Widget) name2Widget(argv[2])))
           {
           convError("installAccelerators","2",argv[2],"Widget");
           DBUG_RETURN (TCL_ERROR);
           }
 
-     if (!(localVar3 = XtParseAcceleratorTable(argv[3])))
+     if (!(localVar3 = (XtAccelerators) XtParseAcceleratorTable(argv[3])))
           {
           convError("installAccelerators","3",argv[3],"XtAccelerators");
           DBUG_RETURN (TCL_ERROR);
@@ -833,7 +875,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("removeAllCallbacks","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -879,7 +921,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("action","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -900,7 +942,7 @@ char        **argv;
         }
 
 
-     if (!(localVar3 = XtParseTranslationTable(argv[3])))
+     if (!(localVar3 = (XtTranslations) XtParseTranslationTable(argv[3])))
           {
           convError("action","3",argv[3],"XtTranslations");
           DBUG_RETURN (TCL_ERROR);
@@ -951,7 +993,7 @@ char        **argv;
 	 DBUG_RETURN (TCL_ERROR);
          }
 
-     if (!(localVar1 = name2Widget(argv[1])))
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
           convError("callback","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
@@ -1220,3 +1262,65 @@ char        **argv;
      }     
 
 
+/* 
+ * void
+ * XtTranslateCoords
+ * 	in: Widget
+ * 	in: Position    # x
+ * 	in: Position    # y
+ * 	out: Position   # root x
+ * 	out: Position   # root y
+ */
+
+int 
+com_translateCoords(clientData, comInterpreter, argc, argv)
+ClientData    clientData;
+Tcl_Interp   *comInterpreter;
+int           argc;
+char        **argv;
+     {
+     Widget localVar1;
+     Position localVar2;
+     Position localVar3;
+     Position localVar4;
+     Position localVar5;
+     char conversionBuffer[100];
+
+     DBUG_ENTER("translateCoords");  
+
+     if (argc != 6) 
+	 {
+	 argcError("translateCoords","",5,argc);
+	 DBUG_RETURN (TCL_ERROR);
+         }
+
+     if (!(localVar1 = (Widget) name2Widget(argv[1])))
+          {
+          convError("translateCoords","1",argv[1],"Widget");
+          DBUG_RETURN (TCL_ERROR);
+          }
+
+     if (!(sscanf(argv[2], "%hd", &localVar2)))
+          {
+          convError("translateCoords","2",argv[2],"Position");
+          DBUG_RETURN (TCL_ERROR);
+          }
+
+     if (!(sscanf(argv[3], "%hd", &localVar3)))
+          {
+          convError("translateCoords","3",argv[3],"Position");
+          DBUG_RETURN (TCL_ERROR);
+          }
+
+     XtTranslateCoords(localVar1,localVar2,localVar3,&localVar4,&localVar5);
+
+     sprintf(conversionBuffer, "%hd", localVar4);
+     Tcl_SetVar(interpreter, argv[4], conversionBuffer, 0);
+
+     sprintf(conversionBuffer, "%hd", localVar5);
+     Tcl_SetVar(interpreter, argv[5], conversionBuffer, 0);
+
+     DBUG_RETURN (TCL_OK);
+     }     
+
+
