@@ -5,7 +5,7 @@
  *      Abteilung fuer Wirtschaftsinformatik
  *      Augasse 2-6,
  *      A-1090 Vienna, Austria
- *      neumann@wu-wien.ac.at, nusser@wu-wien.ac.at
+ *      neumann@@wu-wien.ac.at, nusser@@wu-wien.ac.at
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted, provided
@@ -45,6 +45,10 @@
 #include<X11/Xaw/Scrollbar.h>
 #include<X11/Xaw/AsciiText.h>
 
+#ifdef XEDW
+#include "Xedw/XedwList.h"
+#endif
+
 #ifndef PRER5
 #include <X11/Xaw/Panner.h>
 #include <X11/Xaw/Porthole.h>
@@ -57,12 +61,21 @@
  * files list.c and scrollbar.c.
  */
 
+
 extern void listCallbackProc(
 #if NeedFunctionPrototypes
      Widget, XtPointer, XtPointer
 #endif
 );
 
+#ifdef XEDW
+extern void edwListCallbackProc(
+#if NeedFunctionPrototypes
+     Widget, XtPointer, XtPointer
+#endif
+);
+#endif
+
 extern void scrollbarJumpCallbackProc(
 #if NeedFunctionPrototypes
      Widget, XtPointer, XtPointer
@@ -166,8 +179,7 @@ char        **argv;
           token = strtok(argv[2], " ");
           if (strcmp(token, "type"))
                {
-               fprintf(stderr, 
-                       "Wafe(callActionProc): Missing specification of type, aborting\n");
+               fprintf(stderr, "Wafe(callActionProc): Missing specification of type, aborting\n");
                DBUG_RETURN(TCL_ERROR);
                }
 
@@ -196,15 +208,13 @@ char        **argv;
                          button = Button5;
                     else
                          {
-                         fprintf(stderr, 
-                                 "Wafe(callActionProc): Unknown Button, %s\n", token);
+                         fprintf(stderr, "Wafe(callActionProc): Unknown Button, %s\n", token);
                          DBUG_RETURN(TCL_ERROR);
                          }
                     }
                else
                     {
-                    fprintf(stderr,
-                    "Wafe(callActionProc): This event field (%s) can't be specified", token);
+                    fprintf(stderr, "Wafe(callActionProc): This event field (%s) can't be specified", token);
                     DBUG_RETURN(TCL_ERROR);
                     }
 
@@ -231,8 +241,7 @@ char        **argv;
                     }
                else
                     {
-                    fprintf(stderr, 
-                    "Wafe(callActionProc): This event field (%s) can't be specified", token);
+                    fprintf(stderr, "Wafe(callActionProc): This event field (%s) can't be specified", token);
                     DBUG_RETURN(TCL_ERROR);
                     }
 
@@ -479,18 +488,6 @@ XtPointer  clientData, callData;
                          &x, &y, &win_x, &win_y,
                          &mask);
 
-/*
-     fprintf(stderr, "root=%d/%d, win=%d/%d, parent=%d/%d, wxy=%d/%d\n",
-		x,y,win_x,win_y,xRoot,yRoot,wx,wy);
-
-     screenWidth = DisplayWidth(XtDisplay(topLevel), DefaultScreen(XtDisplay(topLevel)));
-     screenHeight = DisplayHeight(XtDisplay(topLevel), DefaultScreen(XtDisplay(topLevel)));
-
-     fprintf(stderr, "screenwidth=%d, screenheight=%d, x=%d,y=%d, w=%d,h=%d\n",
-		screenWidth, screenHeight,
-		x,y,width,height
-	);
-*/
      XtVaSetValues(w,
                          XtNx, x-offset,
                          XtNy, y-offset,
@@ -508,10 +505,11 @@ XtPointer  clientData, callData;
      char     command[MESSAGE_COMMAND_LENGTH];       
      char    *input = (char *) clientData;
      char    *output = command;
-
+     char     buffer[INT_AS_STRING];  
+     Boolean  isListWidget = (XtClass(w) == listWidgetClass);
+ 
      DBUG_ENTER("excecCallbackProc");
-
-
+     DBUG_PRINT("callback", ("client data %p <%s>\n", input,input));
 
      while (*input != '\0')
           {
@@ -523,6 +521,21 @@ XtPointer  clientData, callData;
                     strcpy (output, XtName(w));
                     output += strlen(XtName(w));
                     }
+               else
+               if (*input == 's' && isListWidget)
+                    {
+                    strcpy (output, ((XawListReturnStruct *)callData)->string);
+                    output += strlen(((XawListReturnStruct *)callData)->string);
+                    }
+               else
+               if (*input == 'i' && isListWidget)
+                    {
+                    sprintf(buffer, "%d", 
+                          ((XawListReturnStruct *)callData)->list_index);
+                    strcpy(output, buffer);
+                    output += strlen(buffer);                    
+                    }
+
                else
 		    {
                     *output = '%';
@@ -597,6 +610,11 @@ char           * arg;
           if ((XtClass(w) == listWidgetClass) && (!strcmp(cbAttribute, "callback")))
               XtAddCallback(w, cbAttribute, listCallbackProc, arg);
           else
+#ifdef XEDW
+          if ((XtClass(w) == xedwListWidgetClass) && (!strcmp(cbAttribute, "callback")))
+              XtAddCallback(w, cbAttribute, edwListCallbackProc, arg);
+          else
+#endif
           if ((XtClass(w) == scrollbarWidgetClass) && (!strcmp(cbAttribute, "scrollProc")))
                 XtAddCallback(w, cbAttribute, scrollbarScrollCallbackProc, arg);
           else
