@@ -49,6 +49,52 @@
 #define done(address, type) \
         { (*toVal).size = sizeof(type); (*toVal).addr = (caddr_t) address; }
 
+/* using non-caching converter for names to widget
+   thanx Christian Holzbaur
+ */
+
+#define	newDone(type, value) \
+	{							\
+	    if (toVal->addr != NULL) {				\
+		if (toVal->size < sizeof(type)) {		\
+		    toVal->size = sizeof(type);			\
+		    return False;				\
+		}						\
+		*(type*)(toVal->addr) = (value);		\
+	    }							\
+	    else {						\
+		static type static_val;				\
+		static_val = (value);				\
+		toVal->addr = (XtPointer)&static_val;		\
+	    }							\
+	    toVal->size = sizeof(type);				\
+	    return True;					\
+	}
+
+Boolean
+NewCvtStringToWidget(dpy, args, num_args, fromVal, toVal, 
+				converter_data)
+     Display *dpy;
+     XrmValue *args;
+     Cardinal *num_args;
+     XrmValue *fromVal;
+     XrmValue *toVal;
+     XtPointer *converter_data;
+{
+    Widget w = NULL;
+    char *name = (char *)fromVal->addr;
+    int i;
+
+    if (*name && !(w = name2Widget(name)))
+         {
+	   XtDisplayStringConversionWarning(dpy, (String)fromVal->addr, XtRWidget);
+	   return False;
+         }
+    else
+         newDone(Widget, w);
+}
+
+
  /* Create a linked list, which keeps track of all created pixmaps,
   * so that we can destroy Colorcells, if they are not longer needed.
   * Only the changePixmap command will use this feature, so pixmaps which
@@ -176,10 +222,24 @@ char        **argv;
         if (!strcmp(argv[3], "None"))
              {
              DBUG_PRINT("pixmap",
-                       ("Setting %s %s to none", argv[1], argv[2]));
+                       ("Setting %s %s to None", argv[1], argv[2]));
              XtVaSetValues(w, argv[2], None, NULL);
              DBUG_RETURN(TCL_OK);
 	     }
+        if (!strcmp(argv[3], "Unspecified"))
+             {
+             DBUG_PRINT("pixmap",
+                       ("Setting %s %s to Unspecified", argv[1], argv[2]));
+             XtVaSetValues(w, argv[2], XtUnspecifiedPixmap, NULL);
+             DBUG_RETURN(TCL_OK);
+	     }
+        if (!strcmp(argv[3], "ParentRelative"))
+             {
+             DBUG_PRINT("pixmap",
+                       ("Setting %s %s to ParentRelative", argv[1], argv[2]));
+             XtVaSetValues(w, argv[2], ParentRelative, NULL);
+             DBUG_RETURN(TCL_OK);
+	     }
 
         /* Now convert the new Pixmap-File, create a new element of the list 
          * and fill it with information.
@@ -202,7 +262,7 @@ char        **argv;
 	          }
              else
 	          {
-                  for (cptr = pixmapListHead; cptr->next != NULL; cptr = cptr->next);
+                  for(cptr = pixmapListHead; cptr->next != NULL; cptr = cptr->next);
                   cptr->next = (PIXMAPINFOPTR)XtMalloc(sizeof(PIXMAPINFO));
                   cptr = cptr->next;
                   cptr->next = NULL;
@@ -219,8 +279,7 @@ char        **argv;
      
              XtVaSetValues(w, argv[2], pixmap, NULL);
  
-             DBUG_PRINT("pixmap",
-             ("Conversion OK, new Pixmap was set"));
+             DBUG_PRINT("pixmap", ("Conversion OK, new Pixmap was set"));
 
              DBUG_RETURN(TCL_OK);
 	     }
@@ -253,7 +312,7 @@ XrmValuePtr toVal;
     XpmAttributes   *attributePtr;
     int              returnValue;
     PIXMAPINFOPTR    pptr, cptr;
-
+    Boolean          toPixmap = *num_args>0;
 
 
     name   = (char *)fromVal->addr;
@@ -268,14 +327,19 @@ XrmValuePtr toVal;
         return;
         }
 
-    if (strcmp(name, "ParentRelative") == 0) 
+    if (strcmp(name, "ParentRelative") == 0 && toPixmap) 
         {
         pixmap = ParentRelative;
         done(&pixmap, Pixmap);
         return;
         }
 
-
+    if (strcmp(name, "Unspecified") == 0 && toPixmap) 
+        {
+        pixmap = XtUnspecifiedPixmap;
+        done(&pixmap, Pixmap);
+        return;
+        }
 
     pixmap = XmuLocateBitmapFile (screen, name,
                                   NULL, 0, NULL, NULL, NULL, NULL);
@@ -314,7 +378,7 @@ XrmValuePtr toVal;
            name, &pixmap, &dummy, NULL)) != XpmSuccess)
            {
            XtStringConversionWarning(name, "Pixmap");
-           fprintf(stderr, "XPM-Error-Code: %d\n", returnValue);
+           fprintf(stderr, "Wafe(convertPixmap): XPM-Error-Code: %d\n", returnValue);
            return;
 	   }
         else
@@ -324,6 +388,62 @@ XrmValuePtr toVal;
 
 #endif                        
     
+
+/* convert string to callback: gustaf Sat Jul 11 15:09:12 MET DST 1992 */
+extern XtCallbackProc execCallbackProc();
+Boolean
+CvtStringToCallback(dpy, args, num_args, fromVal, toVal,
+                                converter_data)
+     Display *dpy;
+     XrmValue *args;
+     Cardinal *num_args;
+     XrmValue *fromVal;
+     XrmValue *toVal;
+     XtPointer *converter_data;
+
+    {
+    static XtCallbackRec cbr[2];
+    static XtCallbackList callback_list = cbr;
+
+    cbr[0].callback = (XtCallbackProc)execCallbackProc;
+    cbr[0].closure = (XtPointer)XtNewString((char *)fromVal->addr);
+/*
+    fprintf(stderr,"callback %p closure = %p <%s> rec %p %p\n", 
+	cbr[0].callback,cbr[0].closure,cbr[0].closure,cbr,&callback_list);
+ */
+    toVal->size = sizeof(XtCallbackList);
+    toVal->addr = (caddr_t)&callback_list;
+    return True;
+    }
+
+
+/* convert string to Pointer: gustaf Sat Jul 11 15:09:12 MET DST 1992 */
+Boolean
+CvtStringToPointer(dpy, args, num_args, fromVal, toVal,
+                                converter_data)
+     Display *dpy;
+     XrmValue *args;
+     Cardinal *num_args;
+     XrmValue *fromVal;
+     XrmValue *toVal;
+     XtPointer *converter_data;
+
+    {
+    static int argc;
+    static char ** argv;
+    int i;
+
+    Tcl_SplitList(interpreter,(char*)fromVal->addr, &argc,&argv);
+/*
+    for(i=0;i<argc;i++) { fprintf(stderr,"%p -- %d: %s %p\n",argv,i,argv[i],argv[i]); }
+ */
+    toVal->size = sizeof(char **);
+    toVal->addr = (caddr_t)&argv;
+    return True;
+    }
+
+
+
 void 
 CvtStringToWidget(args, num_args, fromVal, toVal)
 XrmValuePtr args;
@@ -335,7 +455,6 @@ XrmValuePtr toVal;
     Widget     w;
 
     name   = (char *)fromVal->addr;
-
     if (!(w = name2Widget(name)))
          {
          XtStringConversionWarning(name, "Widget");
@@ -393,8 +512,9 @@ char        **argv;
 
      iconWidth = attrib.width;
      iconHeight = attrib.height;
-
+/*
      fprintf(stderr, "width %d, height %d\n", iconWidth, iconHeight);
+ */
 
      iconWindow = XCreateSimpleWindow(dpy, root, 0, 0, iconWidth, iconHeight, 1, bpix, bpix);
 
@@ -406,8 +526,3 @@ char        **argv;
 #endif
 
 
-
-
-
-
-
