@@ -29,6 +29,8 @@
 
 #include "wafe.h"
 
+#include "rdd.h"
+
 char              *clientStderrHandlerCommand = NULL;
 char              *clientStdinHandlerCommand = NULL;
 char              *clientStdoutHandlerCommand = NULL;
@@ -44,7 +46,7 @@ int                leftBytes = 0;
 
 void
 getInput(client_data, fid, xid)
-XtPointer   client_data;          /* PromptMode YES oder NO  */
+XtPointer   client_data;          /* PromptMode True oder False  */
 int         *fid;
 XtInputId   *xid;
      {
@@ -52,7 +54,7 @@ XtInputId   *xid;
      char   *firstPtr = inputBuffer;
      char   *secondPtr = inputBuffer;
      int     readBytes;
-     int     overFlowFlag = YES;
+     Boolean overFlowFlag = True;
 
      DBUG_ENTER("getInput");
 
@@ -80,7 +82,7 @@ XtInputId   *xid;
                {
                *firstPtr = '\0';     /* One tcl-command is ready */
 
-               overFlowFlag = NO;
+               overFlowFlag = False;
 
                DBUG_PRINT("socket", 
                          ("Parsed Command >%s<", secondPtr));
@@ -145,7 +147,7 @@ XtInputId   *xid;
 
 void
 stdinHandlerProc(client_data, fid, xid)
-XtPointer   client_data; /* Prompt-Mode: Yes oder NO */
+XtPointer   client_data; /* Prompt-Mode: True oder False */
 int         *fid;
 XtInputId   *xid;
      {
@@ -602,3 +604,28 @@ fprintf(stderr, "Command: MORE THAN WE NEED! c=<%d>\n",(int)saveChar);
      DBUG_RETURN(TCL_OK);
      }
 
+
+/*
+ *  The following command is used to access the Drag'n Drop library 
+ */
+
+void
+rddDropCallbackProc(w, command, info)
+Widget   w;
+char     *command;
+RddCallbackStruct   *info;
+     {
+     char *message;
+
+     message = (char *)XtMalloc(info->len + 1);
+     strncpy(message, info->data, info->len);
+     *(message + info->len) = '\0';
+
+     Tcl_SetVar(interpreter, "DROP", message, TCL_GLOBAL_ONLY);
+     XtFree(message);
+
+     if (Tcl_Eval(interpreter, command, 0, NULL) == TCL_ERROR)
+          fprintf(stderr, "Wafe(rddDropCallback): %s\n", interpreter->result);
+    }
+     
+
