@@ -58,20 +58,12 @@
 #include <fcntl.h>
 #endif
 
+#ifdef RDD
+#include "rdd.h"
+#endif
+
 #include "wafe.h"                             
-#include "Version.h"
-
-
-typedef struct _STRINFO
-        {
-        char                *addr;
-        Widget               widget;
-        char                *attribute;
-        struct _STRINFO     *next;
-        } STRINFO, *STRINFOPTR;    
-
-
-STRINFOPTR strHead = NULL;
+#include "version.h"
 
 
 /*
@@ -115,6 +107,8 @@ char *comp;
             tclCommand, comp, name);
      }
 
+
+
 /***********************************************************************************
   *  The following functions maintain the global lists of ResourceLists, one for 
   *  normal widgets and one for constraint resources. They look up the
@@ -128,21 +122,16 @@ WidgetClass wClass;
 XtResourceList  *rList;
      {
      Cardinal  num;
-     RESINFOPTR  ptr;
+     RESINFOPTR  ptr, lptr;
 
      if (resourceList)  /* there are allready some entries in the resource list */
-          for (ptr = resourceList; ptr != NULL; ptr = ptr->next) 
-	        if (ptr->wClass == wClass)
-		     {
-                     *rList = ptr->resources;
-                     return(ptr->num);
-		     }
-
-     XtInitializeWidgetClass(wClass);  /* Just in case it's not yet done... */
-
-     if (resourceList) /* Search for last element in list */
           {
-          for (ptr = resourceList; ptr->next != NULL; ptr = ptr->next);
+          for (lptr = resourceList; lptr != NULL; ptr = lptr, lptr = lptr->next) 
+	        if (lptr->wClass == wClass)
+		     {
+                     *rList = lptr->resources;
+                     return(lptr->num);
+		     }
           ptr->next = (RESINFOPTR) XtMalloc(sizeof(RESINFO));
           ptr = ptr->next;
 	  }
@@ -152,6 +141,7 @@ XtResourceList  *rList;
      ptr->next = NULL;
      ptr->wClass = wClass;
 
+     XtInitializeWidgetClass(wClass);  /* Just in case it is not yet done... */
      XtGetResourceList(wClass, &(ptr->resources), &(ptr->num));
      *rList = ptr->resources;
      return(ptr->num);
@@ -163,19 +153,16 @@ WidgetClass wClass;
 XtResourceList  *rList;
      {
      Cardinal  num;
-     RESINFOPTR  ptr;
+     RESINFOPTR  ptr, lptr;
 
      if (constraintList)  /* there are allready some entries in the resource list */
-          for (ptr = constraintList; ptr != NULL; ptr = ptr->next) 
-	        if (ptr->wClass == wClass)
-		     {
-                     *rList = ptr->resources;
-                     return(ptr->num);
-		     }
-
-     if (constraintList) /* Search for last element in list */
           {
-          for (ptr = constraintList; ptr->next != NULL; ptr = ptr->next);
+          for (lptr = constraintList; lptr != NULL; ptr = lptr, lptr = lptr->next) 
+	        if (lptr->wClass == wClass)
+		     {
+                     *rList = lptr->resources;
+                     return(lptr->num);
+		     }
           ptr->next = (RESINFOPTR) XtMalloc(sizeof(RESINFO));
           ptr = ptr->next;
 	  }
@@ -241,6 +228,68 @@ char           *attribute;
      return(NULL); 
      }
 
+
+MMAttribListPtr *
+MMgetAttribList(w)
+Widget w; 
+{
+     MMWidgetListPtr   *ptr = &MMwidgetListHead;
+     MMWidgetListPtr   ptrTmp;
+
+     while (*ptr) {
+       if ((*ptr)->widget == w) 
+	 return ((MMAttribListPtr*)&((*ptr)->attribList));
+       ptr = &(*ptr)->next;
+     }
+
+     /* not found; it is more efficient to add new widgets 
+      * to the front fo the list 
+      */
+     
+     ptrTmp = MMwidgetListHead;
+     MMwidgetListHead = (MMWidgetListPtr)XtMalloc(sizeof(MMWidgetList));
+/*   fprintf(stderr,"getAttribList: new widgetlist at %p\n",MMwidgetListHead);*/
+     MMwidgetListHead->next = ptrTmp;
+     MMwidgetListHead->widget = w;
+     MMwidgetListHead->attribList = NULL;
+     return((MMAttribListPtr*)&(MMwidgetListHead->attribList));
+
+/* add to the end
+     *ptr = (MMWidgetListPtr)XtMalloc(sizeof(MMWidgetList));
+     (*ptr)->next = NULL;                    
+     (*ptr)->widget = w;
+     (*ptr)->attribList = NULL;
+     return((MMAttribListPtr*)&((*ptr)->attribList));
+*/
+}
+
+void
+MMreplace(al,descriptor,value)
+MMAttribListPtr *al;
+XrmQuark         descriptor;
+char          *value;
+{
+     MMAttribListPtr   *ptr = al;
+     while(*ptr) {
+       if ((*ptr)->attribute == descriptor) {
+	 XtFree((*ptr)->value);
+/*       fprintf(stderr,"replace: freeing value %p\n",(*ptr)->value);*/
+	 (*ptr)->value = value;
+	 return;
+       }
+       ptr = &((*ptr)->next);
+     }
+
+     *ptr = (MMAttribListPtr)XtMalloc(sizeof(MMAttribList));
+     (*ptr)->next = NULL;                    
+     (*ptr)->attribute = descriptor;
+/*     (*ptr)->attribute = XtNewString(descriptor);*/
+/*     fprintf(stderr,"replace: new attriblist %p\n",*ptr);*/
+/*     fprintf(stderr,"replace: new descriptor %s\n",
+       XrmQuarkToString((*ptr)->attribute));
+ */
+     (*ptr)->value = value;
+}
      
 /*****************************************************************************
  *    FUNCTION:  checkArgs4String                                       
@@ -253,6 +302,8 @@ char           *attribute;
  *                                                                          
  *    Used by:   setValues, tclWidgetCommand                                
  *    Uses:      getTypeOfAttribute                                         
+ *    Changes:   freeing callbacks string ressources 
+ *               gustaf Sat Jul 11 15:09:12 MET DST 1992
  *****************************************************************************/
 
 
@@ -262,48 +313,127 @@ Widget      w;
 ArgList     args;
 int         numArgs;
      {
-     STRINFOPTR    ptr;
      int           count;
      int           found = 0;
+     char          *typeOfAtt, *string;
+     MMAttribListPtr *al;
 
      DBUG_ENTER("checkArgs4String");
+     al = MMgetAttribList(w);
+/*
+      fprintf(stderr,"c4String: widget %p attribList %p pointing %p\n",
+      w,al,*al); 
+ */
 
      for (count = 0; count < numArgs; count++)
           {
-          if (!strcmp("String", getTypeOfAttribute(XtClass(w), ParentWidget(w), 
-                                                  args[count].name)))
-               {
-               for (ptr = strHead; ptr != NULL; ptr = ptr->next)
-                    {
-                    if ((ptr->widget == w) && (!strcmp(ptr->attribute, args[count].name)))
-                         {
-                         found = 1;
-                         XtFree(ptr->addr);
-                         ptr->addr = (char *)args[count].value;                         
-                         }
-		    }
+          typeOfAtt = getTypeOfAttribute(XtClass(w), ParentWidget(w), 
+					 args[count].name);
+/*
+          fprintf(stderr,"type = <%s> name= <%s>\n", 
+	  typeOfAtt, args[count].name);
+*/
 
-               if (!found)
-		    {
-                    if (strHead != NULL)
-                         {
-                         for (ptr = strHead; ptr->next != NULL; ptr = ptr->next);
-                         ptr->next = (STRINFOPTR)XtMalloc(sizeof(STRINFO));
-                         ptr = ptr->next;
-                         }
-                    else
-                         ptr = strHead = (STRINFOPTR)XtMalloc(sizeof(STRINFO));
+          if (!strcmp("String", typeOfAtt)) {
+            MMreplace(al,XrmStringToQuark(args[count].name),
+	      (char *)(args[count].value));
 
-                    ptr->next = NULL;                              
-                    ptr->widget = w;
-                    ptr->attribute = XtNewString(args[count].name);
-                    ptr->addr = (char *)args[count].value;                              
-		    }
-	      }
+          } else if (!strcmp("Callback", typeOfAtt)) {
+            MMreplace(al,XrmStringToQuark(args[count].name),
+	      (char *)(((XtCallbackRec *)(args[count].value))->closure));
+
+          } else if (!strcmp("Pointer", typeOfAtt)) {
+            MMreplace(al,XrmStringToQuark(args[count].name),
+		     (char *)(args[count].value));
+          }
+	}
+   DBUG_VOID_RETURN;
+   }
+
+
+
+/*
+ * shadowMM widget key malloced data
+ * frees last malloc-ed data for widget/key and keeps pointer to actual data
+ * gustaf Sat Jul 11 15:09:12 MET DST 1992
+ */
+void
+shadowMM(w, descriptor, string)
+Widget      w;
+char        *descriptor;
+char        *string;
+     {
+     MMreplace(MMgetAttribList(w),XrmStringToQuark(descriptor),string);
+     }
+
+/*
+ * freeGarbageMM widget
+ * frees grabage frames for widget 
+ * gustaf Sat Jul 11 15:09:12 MET DST 1992
+ */
+Widget
+freeGarbageMM(w)
+Widget      w;
+     {
+     MMWidgetListPtr   *ptr = &MMwidgetListHead;
+     MMWidgetListPtr   ptrTmp;
+     MMAttribListPtr   al,alTmp;
+     int           count = 0;
+
+     if (XtIsComposite(w)) 
+         {
+         int numChildren;
+         Widget *children;
+
+         XtVaGetValues(w, XtNnumChildren, &numChildren,
+                          XtNchildren,    &children,    NULL);
+ 
+	 while(numChildren) 
+	     {
+/*
+             fprintf(stderr,"    clearing for %p child of %p\n",
+                   *children,w);
+*/
+             freeGarbageMM(*children);
+             numChildren--;
+             children++;        
+	     }
+         }
+
+     while (*ptr) {
+/*
+       fprintf(stderr,"garbage: ptr=%p *ptr=%p\n",ptr,*ptr);
+*/
+       if ((*ptr)->widget == w) {
+	 al = (MMAttribListPtr)(*ptr)->attribList;
+         while(al) {
+/*
+           fprintf(stderr,"garbage: freeing descriptor %p %s\n",
+		   al->attribute, al->attribute);
+           fprintf(stderr,"garbage: freeing value %p\n",
+		   al->value, al->attribute);
+           fprintf(stderr,"garbage: freeing attribute list %p\n",
+		   al);
+ */
+	   XtFree(al->value);
+/*	   XtFree(al->attribute);*/
+	   alTmp = al->next;
+	   XtFree((char*)al);
+	   al = alTmp;
 	 }
-      DBUG_VOID_RETURN;
-      }
+         ptrTmp = (*ptr)->next; 
+/*	 fprintf(stderr,"garbage: freeing widgetlist %p\n", *ptr);*/
+         XtFree((char*)*ptr);
+         *ptr = ptrTmp;
+         break;
+       }
+       ptr = &(*ptr)->next;
+       count++;
+     }
 
+/*     fprintf(stderr,"counting %d frames\n", count);*/
+     return w;
+}
 
 /*****************************************************************************
  *    FUNCTION:  convert                                                    
@@ -370,25 +500,26 @@ int          *numArgs;             /* RETURN */
                input.size =   strlen(*argv)+1;
                output.addr =  NULL;
 
-               DBUG_PRINT("conv", ("String %s, size %d\n", input.addr,
+               DBUG_PRINT("conv", ("String %s, size %d", input.addr,
                                     input.size));
 
 #ifndef PRER5
                if(XtConvertAndStore(parent, "String", &input, 
                                     type, &output))
-#endif
-
-#ifdef PRER5
+#else
                XtConvert(parent, "String", &input, type, &output);
                if (output.addr)
 #endif
 		    {
                     DBUG_PRINT("conv", ("Konv OK, Gr: %u\n", output.size));
 
-                    if (!strcmp(type, "String"))
-                         {
+                    if (!strcmp(type, "String")) {
 		         argPtr->value = (XtArgVal)XtNewString(output.addr);
-                         }
+/*                         fprintf(stderr,"convert: new String %p <%s>\n",
+				 (char*)argPtr->value,
+				 (char*)argPtr->value);
+ */
+		       }
                     else 
                     if (output.size == sizeof(long))
                          argPtr->value = (XtArgVal) *(long *)output.addr;
@@ -396,11 +527,15 @@ int          *numArgs;             /* RETURN */
                     if (output.size == sizeof(short))
                          argPtr->value = (XtArgVal) *(short *)output.addr;
                     else
+                    if (output.size == sizeof(double)) /* do we need to malloc data? */
+                         argPtr->value = (XtArgVal) (double *)output.addr; 
+                    else 
                     if (output.size == sizeof(char))
                          argPtr->value = (XtArgVal) *(char *)output.addr;
                     else
-                    if (output.size == sizeof(XtArgVal))
-                         argPtr->value = *(XtArgVal *)output.addr;              
+                    if (output.size == sizeof(XtArgVal)) 
+                         argPtr->value = *(XtArgVal *)output.addr;
+
                argPtr++; 
                count++; 
                argv++;
@@ -438,33 +573,32 @@ name2Widget(name)
 char  *name;
      {
      Widget result;
-     char  *longname;
+     char  starname[300];
 
      if (!name)
           return(NULL);
 
-     
-     if (!(result = XtNameToWidget(topLevel, name)))
-          {
-          longname = XtMalloc(strlen(name) + 2);
-          *longname = '*';
-          strcpy (longname + 1, name);
+     *starname = '*';
+     strcpy(&starname[1], name);
 
-          DBUG_PRINT("name2widget", ("Trying: %s", longname));
+     DBUG_PRINT("name2widget", ("Trying: %s", starname));
 
-          if (!(result = XtNameToWidget(topLevel, longname)))
-                  {           
-                  DBUG_PRINT("name2widget", ("Checking topLevel"));
+     if (!(result = XtNameToWidget(topLevel, starname)))
+          {           
+          DBUG_PRINT("name2widget", ("Trying: %s", name));
 
-                  if (!strcmp("topLevel", name))
+          if (!(result = XtNameToWidget(topLevel, name)))
+               {
+               DBUG_PRINT("name2widget", ("Checking topLevel"));
+
+               if (!strcmp("topLevel", name))
                        result = topLevel;
-                  else 
-	               {
-                       fprintf(stderr, "Wafe(name2Widget): %s not found!\n", name);
-                       return (NULL);
-	               }
-	           }
-          XtFree(longname);
+               else 
+	            {
+                    fprintf(stderr, "Wafe(name2Widget): %s not found!\n", name);
+                    return (NULL);
+	            }
+	       }
           }
      return (result);
      }
@@ -475,7 +609,7 @@ char  *name;
  *    Arguments: string containing an instance's name                       
  *    Returns:   source/sink widget of named text widget                       
  *                                                                          
- *    Used by:   some of the generated commands in XawGen as converter proc              
+ *    Used by:   some of the generated commands in XawGen as converter proc
  *****************************************************************************/
 
 Widget 
@@ -513,8 +647,8 @@ char * string;
    
 /*****************************************************************************
  *    FUNCTION:  signalHandler                                             
- *               If wafe receives a SIGINT, SIGTERM, SIDHUP or SIGQUIT     
- *               signal, it is forwarded to the application                
+ *               If wafe receives a signal
+ *               it is forwarded to the application                
  *                                                                         
  *    Arguments: signal number                                             
  *    Returns:   nothing                                                   
@@ -526,13 +660,40 @@ void
 signalHandler(sig)
 int   sig;
      {
-     fprintf(stderr, 
-            "Wafe(main): Signal %d received, forwarding it to application!\n", sig);
- 
-     kill(pid, sig);
-
-     exit(0);
+     DBUG_ENTER ("signalHandler");
+     DBUG_PRINT("signal", ("Signal %d received", sig));
+     if (sig != SIGCLD) {
+        fprintf(stderr, "Wafe(main): Signal %d received!\n", sig);
+        kill(pid, sig);
+     	fprintf(stderr, "Wafe(main): forwarding it to application!\n");
+        exit(0);
      }
+     DBUG_VOID_RETURN;
+}
+/*****************************************************************************
+ *    FUNCTION:  XIOHandler                                             
+ *               If wafe receives a XIOError
+ *               SIGTERM is sent to the application
+ *                                                                         
+ *    Arguments: display, error event
+ *    Returns:   nothing                                                   
+ *                                                                         
+ *    Used by:   main                                                      
+ *****************************************************************************/
+
+int
+IOErrorHandler(dpy,xe)
+Display *dpy;
+XErrorEvent *xe;
+{
+     DBUG_ENTER ("IOErrorHandler");
+
+     fprintf(stderr, "Wafe(main): XIOError, terminating child!\n");
+     kill(pid, SIGTERM);
+/*   exit(0); */
+     DBUG_VOID_RETURN;
+}
+
 
 /*****************************************************************************
  *    FUNCTION: iSocketPair
@@ -637,8 +798,9 @@ char **argv;
 char **env;
      {
      int                    i = 0;
-     int                    promptMode = YES;
-     int                    execMode = NO;
+     Boolean                promptMode = True;
+     Boolean                execMode = False;
+     Boolean                opt_p = False;
      int                    args = 0; 
      int                    cargc = 0;
      char                 **cargv;    
@@ -647,7 +809,8 @@ char **env;
      char                   file[50];
      char                  *charPtr;
      char                  *execString;
-     char                 application[50];
+     char                 application[100];
+     char                 packages[100];
 
      int                    sp[4];  
      int                    ep[4];  
@@ -660,6 +823,7 @@ char **env;
      DBUG_ENTER ("main");
      DBUG_PROCESS (argv[0]);
 
+     strHead = &STRINFOroot;
      cargvCount = cargv = (char **)XtMalloc((argc * sizeof(char *)) + 1);
 
      /* In standard mode, the class will be derived from the application's name,
@@ -667,6 +831,7 @@ char **env;
        */
 
      strcpy(class, argv[0]);
+     application[0] = '\0';
 
      /*
       * Argument parsing loop - build new argument list without wafe's 
@@ -689,7 +854,7 @@ char **env;
  
            if (argv[args][2] == 'n')            /* Turn prompt mode off */
 	        {                              
-                promptMode = NO;               
+                promptMode = False;               
                 args++;
                 }
            else
@@ -708,7 +873,7 @@ char **env;
 
            if (argv[args][2] == 'i')            /* Enter input mode  */
 	        {                            
-                inputMode  = YES;            
+                inputMode  = True;            
                 args++;
                 }
            else
@@ -719,8 +884,8 @@ char **env;
 		int     comLength = 0;
 
 		args++;
-                execMode  = YES;     
-		fileMode = YES;
+                execMode  = True;     
+		fileMode = True;
 		execString = argv[args];
 
 		if (execString == NULL)
@@ -736,7 +901,7 @@ char **env;
 
            if (argv[args][2] == 'd')            /* Enter direct mode */
 	        {                           
-                directMode = YES;
+                directMode = True;
 
                 toClient = fileno(stdout);
                 fromClient = fileno(stdin);
@@ -755,16 +920,25 @@ char **env;
                 args++;
 	        }
            else
+
+           if (argv[args][2] == 'p')
+	        {
+		opt_p = True;
+                strcpy(class, argv[args+1]);
+                strcpy(application, argv[args+1]);
+                args += 2;
+	        }
+           else
                              /***  File - Mode  ***/
 
            if (argv[args][2] == 'f')        /* Enter file mode */
                 {
                 if (argv[args][3] == 'i')    /* For convenience: --fi == --f --i */
 		     {
-                     inputMode = YES;
+                     inputMode = True;
 		     }
 
-                fileMode = YES;
+                fileMode = True;
                 strcpy(file, argv[args+1]);   /* Next Arg = File to execute */
                 strcpy(class, file);
 
@@ -808,7 +982,8 @@ char **env;
      *  We will need this information when we execute the application process ...
      */
 
-     strcpy(application, class); 
+     if (!application[0]) 
+       strcpy(application, class); 
 
      /*
        * If the name contains a dot, which is not allowed in Xt's class names, substitute it
@@ -838,12 +1013,16 @@ char **env;
           class[1] = toupper(class[1]);
 	  }
      else
-          class[0] =toupper(class[0]);
+          class[0] = toupper(class[0]);
 
      /* Must initialize here, so that Xt can strip off its arguments */
 
      topLevel = XtVaAppInitialize(&appContext, class, NULL, 0, &cargc, cargv, NULL, NULL); 
 
+#ifdef RDD
+     rddInit(topLevel, appContext);
+#endif
+
      DBUG_PRINT("start", ("App's args (cargc = %d):", cargc)); 
 
      for(i = 0; cargv[i] != NULL; i++)
@@ -913,13 +1092,14 @@ printf("ep %d %d %d %d\n",ep[0],ep[1],ep[2],ep[3]);
                close(sp[1]);              /* For regular communication ..*/
                close(sp[0]);              /* via stdin and stdout!       */
 
-               if ((*application != 'x') && (*application != 'X'))
+               if (!opt_p && (*application != 'x') && (*application != 'X'))
 		    {
-                    fprintf(stderr, "Wafe(main):Wrong File was started, aborting\n");
+                    fprintf(stderr, "Wafe(main): Wrong File was started, aborting\n");
+		    sleep(1);
                     exit(-1);
 		  }
 
-               cargv[0] = application+1;
+               cargv[0] = opt_p ? application : application+1;
 
                execvp(cargv[0], cargv);   /* execute the client-program  */  
    
@@ -959,6 +1139,10 @@ printf("ep %d %d %d %d\n",ep[0],ep[1],ep[2],ep[3]);
           signal(SIGQUIT, signalHandler);
           signal(SIGINT, signalHandler);
           signal(SIGHUP, signalHandler);
+          signal(SIGPIPE, signalHandler);
+          signal(SIGCLD, signalHandler);
+
+	  XSetIOErrorHandler(IOErrorHandler);
 
           }
 
@@ -978,7 +1162,7 @@ printf("ep %d %d %d %d\n",ep[0],ep[1],ep[2],ep[3]);
 
      if ((directMode) && (fileMode))
           {
-          fprintf(stderr, "Wafe: Invalid direct-mode and file-mode, aborting\n");
+          fprintf(stderr, "Wafe: Invalid combination direct-mode and file-mode, aborting\n");
           exit(-1);
 	  }
 
@@ -990,7 +1174,7 @@ printf("ep %d %d %d %d\n",ep[0],ep[1],ep[2],ep[3]);
 printf("registering inputhandler fromClient %d\n",fromClient);
 */
           XtAppAddInput(appContext, fromClient, (XtPointer)XtInputReadMask,
-                        getInput, (XtPointer)promptMode); 
+                        getInput, (XtPointer)(int)promptMode); /* to make gcc happy */
 
 
           if (!directMode)
@@ -1023,12 +1207,46 @@ printf("registering inputhandler comWafe %d\n",comWafe);
 
      interpreter = Tcl_CreateInterp();
 
-     Tcl_SetVar(interpreter, "WAFEVERSION", VERSION, TCL_GLOBAL_ONLY);
+     sprintf(packages,"%s %s %s %s %s %s"
+#ifdef RDD
+     ,"RDD"
+#else
+     ,""
+#endif
+#ifdef PLOTTER
+     ,"PLOTTER"
+#else
+     ,""
+#endif
+#ifdef XAW3D
+     ,"XAW3D"
+#else
+     ,""
+#endif
+#ifdef XEDW
+     ,"XEDW"
+#else
+     ,""
+#endif
+#ifdef XPM
+     ,"XPM"
+#else
+     ,""
+#endif
+#ifdef XC
+     ,"XC"
+#else
+     ,""
+#endif
+     );
+
 #ifdef PRER5
      Tcl_SetVar(interpreter, "XVERSION", "R4", TCL_GLOBAL_ONLY);
 #else
      Tcl_SetVar(interpreter, "XVERSION", "R5", TCL_GLOBAL_ONLY);
 #endif
+     Tcl_SetVar(interpreter, "WAFEVERSION", VERSION, TCL_GLOBAL_ONLY);
+     Tcl_SetVar(interpreter, "PACKAGES", packages, TCL_GLOBAL_ONLY);
 
      /* This procedure registers all widget tcl-commands (compare 
       * to athenaW.c) and initializes all widget classes (this
@@ -1045,6 +1263,10 @@ printf("registering inputhandler comWafe %d\n",comWafe);
 #endif
 
 
+{  COM_PROTOTYPE(Tcl_ListCmd)
+   Tcl_CreateCommand(interpreter, "llist", Tcl_ListCmd, NULL, NULL); 
+}
+
      /************************************************************/
      /* Now the additional tcl-commands are registered           */
      /************************************************************/
@@ -1083,31 +1305,60 @@ printf("registering inputhandler comWafe %d\n",comWafe);
                                          com_unregisterStdinHandler, NULL, NULL);
      Tcl_CreateCommand(interpreter, "addTimeOut", com_addTimeOut, NULL, NULL);
 
-     Tcl_CreateCommand(interpreter, "ownSelection",
-                                                   com_ownSelection, NULL, NULL);
+     Tcl_CreateCommand(interpreter, "ownSelection", com_ownSelection, NULL, NULL);
+#ifdef XEDW
+     Tcl_CreateCommand(interpreter, "edwListChange",  com_edwListChange, NULL, NULL);
+#endif
      /*
-      * The following two include files contain the prototypings as well as the
+      * The following include files contain the prototypings as well as the
       * Tcl_createCommand statements for the automatically gernerated functions
       */
 
 #include "XawGen.tcc"
 #include "XtGen.tcc"
 
-#ifdef XPM
-     XtAddConverter("String", "Pixmap", CvtStringToPixmapOrBitmap, NULL, 0);
-     XtAddConverter("String", "Bitmap", CvtStringToPixmapOrBitmap, NULL, 0);
-
-     Tcl_CreateCommand(interpreter, "changePixmap",
-                                                   com_changePixmap, NULL, NULL);
-     Tcl_CreateCommand(interpreter, "setIconPixmap",   com_setIconPixmap, NULL, NULL);
+#ifdef RDD
+#include "rddGen.tcc"
+#endif
+#ifdef XC
+#include "xcGen.tcc"
+#endif
+#ifdef PLOTTER
+#include "AtHandCraft.tcc"
+#include "AtGen.tcc"
 #endif
 
-     XtAddConverter("String", "Widget", CvtStringToWidget, NULL, 0);
+#ifdef XPM
+{ XtConvertArgRec argrec;  /* we need it only to flag bitmap or pixmap */
+     XtAddConverter(XtRString, XtRPixmap, CvtStringToPixmapOrBitmap, &argrec, 1);
+}
+     XtAddConverter(XtRString, XtRBitmap, CvtStringToPixmapOrBitmap, NULL, 0);
+
+     Tcl_CreateCommand(interpreter, "changePixmap", com_changePixmap, NULL, NULL);
+     Tcl_CreateCommand(interpreter, "setIconPixmap", com_setIconPixmap, NULL, NULL);
+#endif
+
+/*  using non-caching converter for names to widget to avoid dangling references
+ *  thanx Christian Holzbaur
+ */
+     XtSetTypeConverter(XtRString, XtRWidget, 
+        (XtTypeConverter)NewCvtStringToWidget, 
+	NULL, 0, XtCacheNone, NULL);
+/*
+ *   XtAddConverter(XtRString, XtRWidget, CvtStringToWidget, NULL, 0);
+ */
+
+     XtSetTypeConverter(XtRString, XtRCallback, 
+	(XtTypeConverter)CvtStringToCallback, 
+	NULL, 0, XtCacheNone, NULL);
+     XtSetTypeConverter(XtRString, XtRPointer, 
+	(XtTypeConverter)CvtStringToPointer, 
+	NULL, 0, XtCacheNone, NULL);
 
      if (execMode)
           {
           if(Tcl_Eval(interpreter, execString, 0, NULL) == TCL_ERROR)
-	        fprintf(stderr, "Wafe(execute mode): %s\n", interpreter->result);
+               fprintf(stderr, "Wafe(execute mode): %s\n", interpreter->result);
 	  }
 
      if ((fileMode) && (!execMode))
@@ -1119,7 +1370,7 @@ printf("registering inputhandler comWafe %d\n",comWafe);
           sprintf(intBuffer, "%d", cargc);
           Tcl_SetVar(interpreter, "ARGC",  intBuffer, TCL_GLOBAL_ONLY);
 
-          for (i = 0; env[i]  != NULL; i++);
+          for (i = 0; env[i] != NULL; i++);
           Tcl_SetVar(interpreter, "ENV", Tcl_Merge(i, env), TCL_GLOBAL_ONLY);
 
           if (Tcl_EvalFile(interpreter, file) == TCL_ERROR)
@@ -1135,8 +1386,12 @@ printf("registering inputhandler comWafe %d\n",comWafe);
           SEND(app_data.init_com);
 	  }
 
+#ifdef RDD
+     rddAppMainLoop(appContext);
+#else
      XtAppMainLoop(appContext);
- 
+#endif
+
      DBUG_VOID_RETURN;
      }
 
