@@ -1,15 +1,6 @@
-
 #include <dbug.h>
 #include <tcl.h>
 
-/*
-  * If you are using BSD UNIX, we will use the socketpair call,
-  * otherwise we have to work with streams.
-  */
-
-/* #define STREAMS */
-
-
 #define SEND(x) write(toClient, x ,strlen(x)); write(toClient, "\n", 1)
 #define ParentWidget(w) ((w) != topLevel ? XtParent(w) : (w))
 
@@ -69,14 +60,42 @@ WAFE_EXTERN int            toClient;    /* Standard Communication Channel     */
 WAFE_EXTERN int            fromClient;  /* Standard Communication Channel     */
 WAFE_EXTERN int            errorClient; /* For error messages of application  */
 
-WAFE_EXTERN int INITIALIZE(directMode, NO); /* Flags for the different Modes  */
-WAFE_EXTERN int INITIALIZE(fileMode, NO);
-WAFE_EXTERN int INITIALIZE(inputMode, NO);
-
-
+WAFE_EXTERN int INITIALIZE(directMode, False); /* Flags for the different Modes  */
+WAFE_EXTERN int INITIALIZE(fileMode, False);
+WAFE_EXTERN int INITIALIZE(inputMode, False);
 WAFE_EXTERN char INITIALIZE(promptChar, '%');
 
 
+
+typedef struct _STRINFO
+        {
+        char                *addr;
+        Widget               widget;
+        char                *attribute;
+        struct _STRINFO     *next;
+        } STRINFO, *STRINFOPTR;
+
+typedef struct _MMWidgetList
+        {
+        Widget               widget;
+        struct _MMattribList  *attribList;
+        struct _MMWidgetList  *next;
+        } MMWidgetList, *MMWidgetListPtr;
+
+typedef struct _MMAttribList
+        {
+/*        char                *attribute;*/
+        XrmQuark            attribute;
+        char                *value;
+        struct _MMAttribList  *next;
+        } MMAttribList, *MMAttribListPtr;
+
+
+WAFE_EXTERN STRINFO STRINFOroot;
+WAFE_EXTERN STRINFOPTR strHead;
+WAFE_EXTERN MMWidgetListPtr MMwidgetListHead;
+
+
 WAFE_EXTERN Widget name2Widget(
 #if NeedFunctionPrototypes
      char *
@@ -107,6 +126,31 @@ WAFE_EXTERN Cardinal getConOfClass(
 #endif
 );
 
+WAFE_EXTERN void MMreplace(
+#if NeedFunctionPrototypes
+/*    MMAttribListPtr *, char *, char * */
+    MMAttribListPtr *, XrmQuark, char *
+#endif
+);
+
+WAFE_EXTERN MMAttribListPtr * MMgetAttribList(
+#if NeedFunctionPrototypes
+    Widget
+#endif
+);
+
+WAFE_EXTERN void shadowMM(
+#if NeedFunctionPrototypes
+     Widget, char *, char *
+#endif
+);
+
+WAFE_EXTERN Widget freeGarbageMM(
+#if NeedFunctionPrototypes
+     Widget
+#endif
+);
+
 #ifdef MAIN
 
 typedef struct _RESINFO
@@ -198,6 +242,7 @@ COM_PROTOTYPE(com_stdoutHandler)
 COM_PROTOTYPE(com_unregisterStdoutHandler)
 COM_PROTOTYPE(com_addTimeOut)
 
+
 extern void timerProc(
 #if NeedFunctionPrototypes
      XtPointer, XtIntervalId *
@@ -215,6 +260,8 @@ extern void CvtStringToPixmapOrBitmap(
      XrmValuePtr, Cardinal *, XrmValuePtr, XrmValuePtr
 #endif
 );
+COM_PROTOTYPE(com_changePixmap)
+COM_PROTOTYPE(com_setIconPixmap)
 #endif
 
 extern void CvtStringToWidget(
@@ -223,10 +270,23 @@ extern void CvtStringToWidget(
 #endif
 );
 
-#ifdef XPM
-COM_PROTOTYPE(com_changePixmap)
-COM_PROTOTYPE(com_setIconPixmap)
+extern XtTypeConverter NewCvtStringToWidget(
+#if NeedFunctionPrototypes
+     Display*,XrmValue*,Cardinal*,XrmValue*,XrmValue*,XtPointer*
 #endif
+);
+
+extern void CvtStringToCallback(
+#if NeedFunctionPrototypes
+     XrmValuePtr, Cardinal *, XrmValuePtr, XrmValuePtr
+#endif
+);
+extern void CvtStringToPointer(
+#if NeedFunctionPrototypes
+     XrmValuePtr, Cardinal *, XrmValuePtr, XrmValuePtr
+#endif
+);
+
      
 /*
  * Functions from file STRIPCHART.C
@@ -241,6 +301,10 @@ COM_PROTOTYPE(com_stripChart)
 COM_PROTOTYPE(com_listAppend)
 COM_PROTOTYPE(com_listChange)
 
+#ifdef XEDW
+COM_PROTOTYPE(com_edwListChange)
+#endif
+
 /*
  * Functions and extern variables from file ASCIITEXT.C
  */
@@ -347,6 +411,15 @@ extern char *getTypeOfAttribute(
 #endif
 );
 
+#ifdef RDD
+#include "rdd.h"
+extern void rddDropCallbackProc(
+#if NeedFunctionPrototypes
+      Widget, char *, RddCallbackStruct *
+#endif
+);
 #endif
 
 
+#endif
+
