@@ -5,7 +5,7 @@
  *	including interpreter creation and deletion, command creation
  *	and deletion, and command parsing and execution.
  *
- * Copyright 1987-1991 Regents of the University of California
+ * Copyright 1987-1992 Regents of the University of California
  * Permission to use, copy, modify, and distribute this
  * software and its documentation for any purpose and without
  * fee is hereby granted, provided that the above copyright
@@ -16,7 +16,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /user6/ouster/tcl/RCS/tclBasic.c,v 1.128 91/10/31 16:41:13 ouster Exp $ SPRITE (Berkeley)";
+static char rcsid[] = "$Header: /user6/ouster/tcl/RCS/tclBasic.c,v 1.131 92/06/21 14:09:41 ouster Exp $ SPRITE (Berkeley)";
 #endif
 
 #include "tclInt.h"
@@ -160,6 +160,7 @@ Tcl_CreateInterp()
     iPtr->filePtrArray = NULL;
     for (i = 0; i < NUM_REGEXPS; i++) {
 	iPtr->patterns[i] = NULL;
+	iPtr->patLengths[i] = -1;
 	iPtr->regexps[i] = NULL;
     }
     iPtr->cmdCount = 0;
@@ -501,6 +502,7 @@ Tcl_Eval(interp, cmd, flags, termPtr)
 
     iPtr->numLevels++;
     if (iPtr->numLevels > MAX_NESTING_DEPTH) {
+	iPtr->numLevels--;
 	iPtr->result =  "too many nested calls to Tcl_Eval (infinite loop?)";
 	return TCL_ERROR;
     }
@@ -1034,3 +1036,39 @@ Tcl_VarEval(interp, p, va_alist)
     }
     return result;
 }
+
+/*
+ *----------------------------------------------------------------------
+ *
+ * Tcl_GlobalEval --
+ *
+ *	Evaluate a command at global level in an interpreter.
+ *
+ * Results:
+ *	A standard Tcl result is returned, and interp->result is
+ *	modified accordingly.
+ *
+ * Side effects:
+ *	The command string is executed in interp, and the execution
+ *	is carried out in the variable context of global level (no
+ *	procedures active), just as if an "uplevel #0" command were
+ *	being executed.
+ *
+ *----------------------------------------------------------------------
+ */
+
+int
+Tcl_GlobalEval(interp, command)
+    Tcl_Interp *interp;		/* Interpreter in which to evaluate command. */
+    char *command;		/* Command to evaluate. */
+{
+    register Interp *iPtr = (Interp *) interp;
+    int result;
+    CallFrame *savedVarFramePtr;
+
+    savedVarFramePtr = iPtr->varFramePtr;
+    iPtr->varFramePtr = NULL;
+    result = Tcl_Eval(interp, command, 0, (char **) NULL);
+    iPtr->varFramePtr = savedVarFramePtr;
+    return result;
+}
